@@ -1,6 +1,6 @@
 package Dancer::Plugin::Email;
 
-our $VERSION = '1.0201'; # VERSION
+our $VERSION = '1.0300'; # VERSION
 
 use Dancer qw(:syntax debug warning);
 use Dancer::Plugin;
@@ -30,7 +30,7 @@ register email => sub {
     my $email = MIME::Entity->build(
         Charset  => 'utf-8',
         Encoding => 'quoted-printable',
-        %headers, # %headers may overwrite type, charset, and encoding
+        %headers,
         Data => $params->{body} || $params->{message},
     );
     if ($attach) {
@@ -85,6 +85,10 @@ register email => sub {
     }
     my %sendmail_arg = ( transport => $transport );
     $sendmail_arg{from} = $sender if defined $sender;
+    if ( $headers{bcc} ) {
+        sendmail $email, { %sendmail_arg, to => $headers{bcc} };
+        $email->head->delete('bcc');
+    }
     return sendmail $email, \%sendmail_arg;
 };
 
@@ -108,7 +112,7 @@ Dancer::Plugin::Email - Simple email sending for Dancer applications
 
 =head1 VERSION
 
-version 1.0201
+version 1.0300
 
 =head1 SYNOPSIS
 
@@ -170,6 +174,7 @@ so wrapping calls to C<email> with try/catch is recommended.
                 sender  => 'bounces-here@foo.com', # optional
                 from    => 'bob@foo.com',
                 to      => 'sue@foo.com, jane@foo.com',
+                bcc     => 'sam@foo.com',
                 subject => 'allo',
                 body    => 'Dear Sue, ...<img src="cid:blabla">',
                 multipart => 'related', # optional, see below
